"""A setuptools based setup module. Copied wholesale from
https://github.com/pypa/sampleproject
and edited.

See:
https://packaging.python.org/en/latest/distributing.html
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

# from version import __release__ as version
# for python3.x compatibility, ditch execfile
exec(compile(open('geco_stat/_version.py', "rb").read(), 'geco_stat/_version.py', 'exec'))

here = path.abspath(path.dirname(__file__))

long_description = """
geco_stat can be used to easily generate histograms, statistics, and
anomaly reports for timing signals generated by LIGO interferometers. It is
meant to simplify the handling of massive amounts of diagnostic data by
providing a simple, organized interface to relevant statistics, easy
progress tracking for large jobs, effortless data visualization, and convenient
ways to combine reports, so that very long timeseries can be efficiently
analyzed in parallel and then recombined into single, monolithic reports
covering entire eras.
"""

setup(
    name='geco_stat',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version = __release__,

    description='Diagnostic tools for the advanced LIGO timing distribution system.',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/stefco/geco_stat',

    # Author details
    author='Stefan Countryman',
    author_email='stefan.countryman@ligo.org',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 2 - Pre-Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Physics',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='lsc ligo geco columbia timing diagnostic gravitational waves frame file',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    # packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    packages=['geco_stat'],

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    # py_modules=["geco_stat"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['matplotlib','numpy','h5py','tendo'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,docs,test]
    extras_require={
    # dev extras should also exist in the Makefile for robustness on old setups
        'dev': ["pip>=1.4", "setuptools>=0.9", "wheel>=0.21", "twine", "ipython"],
        'docs': ["sphinx"],
    #     'test': ['coverage'],
    },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    # package_data={
    #     'sample': ['package_data.dat'],
    # },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('my_data', ['data/data_file'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
    #     'console_scripts': [
    #         'sample=sample:main',
    #     ],
    # },
)
